@@ -5,11 +5,7 @@ from .helpers.std import Std
 class NineMangaCom(NineHelper, Std):
     _local_storage = None
 
-    def get_archive_name(self) -> str:
-        idx = self.get_chapter_index(True).split('-')
-        return self.normal_arc_name(idx)
-
-    def get_chapter_index(self, no_increment=False) -> str:
+    def get_chapter_index(self) -> str:
         return str(self.chapter_id)
 
     def get_main_content(self):
@@ -34,6 +30,10 @@ class NineMangaCom(NineHelper, Std):
             items.append('{}{}-10-1.html'.format(self.domain, u.group(1)))
         return items
 
+    def get_files_on_page(self, content):
+        parser = self.document_fromstring(content)
+        return self._images_helper(parser, 'img.manga_pic')
+
     def get_files(self):
         content = self._get_page_content(self.chapter)
         parser = self.document_fromstring(content)
@@ -45,6 +45,9 @@ class NineMangaCom(NineHelper, Std):
             images += self.get_files_on_page(content)
         return images
 
+    def prepare_cookies(self):
+        self._base_cookies(self.get_url())
+
     def book_meta(self) -> dict:
         # todo meta
         pass
